@@ -19,10 +19,9 @@ from .dashboard_methods import *
 
 
 class PrecisionComponent(ExplainerComponent):
-    def __init__(self, explainer, title="Precision Plot",
-                    header_mode="none", name=None,
+    def __init__(self, explainer, title="Precision Plot", name=None,
                     hide_cutoff=False, hide_binsize=False, hide_binmethod=False,
-                    hide_multiclass=False,
+                    hide_multiclass=False, hide_selector=False, pos_label=None,
                     bin_size=0.1, quantiles=10, cutoff=0.5,
                     quantiles_or_binsize='bin_size', multiclass=False):
         """Shows a precision graph with toggles.
@@ -32,33 +31,41 @@ class PrecisionComponent(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Precision Plot".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
             hide_binsize (bool, optional): hide binsize/quantiles slider. Defaults to False.
+            hide_selector(bool, optional): hide pos label selector. Defaults to False.
             hide_binmethod (bool, optional): Hide binsize/quantiles toggle. Defaults to False.
             hide_multiclass (bool, optional): Hide multiclass toggle. Defaults to False.
+            hide_selector (bool, optional): Hide pos label selector. Default to True.
+            pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             bin_size (float, optional): Size of bins in probability space. Defaults to 0.1.
             quantiles (int, optional): Number of quantiles to divide plot. Defaults to 10.
             cutoff (float, optional): Cutoff to display in graph. Defaults to 0.5.
             quantiles_or_binsize (str, {'quantiles', 'bin_size'}, optional): Default bin method. Defaults to 'bin_size'.
             multiclass (bool, optional): Display all classes. Defaults to False.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
         self.hide_cutoff, self.hide_binsize = hide_cutoff, hide_binsize
         self.hide_binmethod, self.hide_multiclass = hide_binmethod, hide_multiclass
+        self.hide_selector = hide_selector
         
         self.bin_size, self.quantiles, self.cutoff = bin_size, quantiles, cutoff 
         self.quantiles_or_binsize, self.multiclass = quantiles_or_binsize, multiclass
         self.cutoff_name = 'precision-cutoff-' + self.name
+
+        self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
-    def _layout(self):
+    def layout(self):
         return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([self.selector.layout()], width=3), hide=self.hide_selector)
+            ], justify="end"),
             dbc.Row([
                 dbc.Col([
                     html.Div([
@@ -162,10 +169,10 @@ class PrecisionComponent(ExplainerComponent):
              Input('precision-binsize-or-quantiles-'+self.name, 'value'),
              Input('precision-cutoff-'+self.name, 'value'),
              Input('precision-multiclass-'+self.name, 'checked'),
-             Input('pos-label', 'value')],
-            [State('tabs', 'value')],
+             Input('pos-label-'+self.name, 'value')],
+            #[State('tabs', 'value')],
         )
-        def update_precision_graph(bin_size, quantiles, bins, cutoff, multiclass, pos_label, tab):
+        def update_precision_graph(bin_size, quantiles, bins, cutoff, multiclass, pos_label):
             if bins == 'bin_size':
                 return self.explainer.plot_precision(
                     bin_size=bin_size, cutoff=cutoff, multiclass=multiclass, pos_label=pos_label)
@@ -176,9 +183,9 @@ class PrecisionComponent(ExplainerComponent):
 
 
 class ConfusionMatrixComponent(ExplainerComponent):
-    def __init__(self, explainer, title="Confusion Matrix",
-                    header_mode="none", name=None,
+    def __init__(self, explainer, title="Confusion Matrix", name=None,
                     hide_cutoff=False, hide_percentage=False, hide_binary=False,
+                    hide_selector=False, pos_label=None,
                     cutoff=0.5, percentage=True, binary=True):
         """Display confusion matrix component
 
@@ -187,28 +194,34 @@ class ConfusionMatrixComponent(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Confusion Matrix".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
             hide_percentage (bool, optional): Hide percentage toggle. Defaults to False.
             hide_binary (bool, optional): Hide binary toggle. Defaults to False.
+            hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): Default cutoff. Defaults to 0.5.
             percentage (bool, optional): Display percentages instead of counts. Defaults to True.
             binary (bool, optional): Show binary instead of multiclass confusion matrix. Defaults to True.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
         self.hide_cutoff, self.hide_percentage = hide_cutoff, hide_percentage
-        self.hide_binary = hide_binary
+        self.hide_binary, self.hide_selector = hide_binary, hide_selector
         self.cutoff, self.percentage, self.binary = cutoff, percentage, binary
         self.cutoff_name = 'confusionmatrix-cutoff-' + self.name
+
+        self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
-    def _layout(self):
+    def layout(self):
         return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([self.selector.layout()], width=3), hide=self.hide_selector)
+            ], justify="end"),
             dcc.Loading(id='loading-confusionmatrix-graph-'+self.name, 
                             children=[dcc.Graph(id='confusionmatrix-graph-'+self.name)]),
             make_hideable(
@@ -259,19 +272,17 @@ class ConfusionMatrixComponent(ExplainerComponent):
             [Input('confusionmatrix-cutoff-'+self.name, 'value'),
              Input('confusionmatrix-percentage-'+self.name, 'checked'),
              Input('confusionmatrix-binary-'+self.name, 'checked'),
-             Input('pos-label', 'value')],
-            [State('tabs', 'value')],
+             Input('pos-label-'+self.name, 'value')],
         )
-        def update_confusionmatrix_graph(cutoff, normalized, binary, pos_label, tab):
+        def update_confusionmatrix_graph(cutoff, normalized, binary, pos_label):
             return self.explainer.plot_confusion_matrix(
                         cutoff=cutoff, normalized=normalized, binary=binary, pos_label=pos_label)
 
 
 class LiftCurveComponent(ExplainerComponent):
-    def __init__(self, explainer, title="Lift Curve",
-                    header_mode="none", name=None,
-                    hide_cutoff=False, hide_percentage=False,
-                    cutoff=0.5, percentage=True):
+    def __init__(self, explainer, title="Lift Curve", name=None,
+                    hide_cutoff=False, hide_percentage=False, hide_selector=False,
+                    pos_label=None, cutoff=0.5, percentage=True):
         """Show liftcurve component
 
         Args:
@@ -279,25 +290,32 @@ class LiftCurveComponent(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Lift Curve".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
             hide_percentage (bool, optional): Hide percentage toggle. Defaults to False.
+            hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): Cutoff for lift curve. Defaults to 0.5.
             percentage (bool, optional): Display percentages instead of counts. Defaults to True.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
         self.hide_cutoff, self.hide_percentage = hide_cutoff, hide_percentage
+        self.hide_selector = hide_selector
         self.cutoff, self.percentage = cutoff, percentage
         self.cutoff_name = 'liftcurve-cutoff-' + self.name
+
+        self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
-    def _layout(self):
+    def layout(self):
         return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([self.selector.layout()], width=3), hide=self.hide_selector)
+            ], justify="end"),
             html.Div([
                         dcc.Loading(id='loading-lift-curve-'+self.name, 
                                 children=[dcc.Graph(id='liftcurve-graph-'+self.name)]),
@@ -334,18 +352,16 @@ class LiftCurveComponent(ExplainerComponent):
             Output('liftcurve-graph-'+self.name, 'figure'),
             [Input('liftcurve-cutoff-'+self.name, 'value'),
              Input('liftcurve-percentage-'+self.name, 'checked'),
-             Input('pos-label', 'value')],
-            [State('tabs', 'value')],
+             Input('pos-label-'+self.name, 'value')],
         )
-        def update_precision_graph(cutoff, percentage, pos_label, tab):
+        def update_precision_graph(cutoff, percentage, pos_label):
             return self.explainer.plot_lift_curve(cutoff=cutoff, percentage=percentage, pos_label=pos_label)
 
 
 class ClassificationComponent(ExplainerComponent):
-    def __init__(self, explainer, title="Classification Plot",
-                    header_mode="none", name=None,
-                    hide_cutoff=False, hide_percentage=False,
-                    cutoff=0.5, percentage=True):
+    def __init__(self, explainer, title="Classification Plot", name=None,
+                    hide_cutoff=False, hide_percentage=False, hide_selector=False,
+                    pos_label=None, cutoff=0.5, percentage=True):
         """Shows a barchart of the number of classes above the cutoff and below
         the cutoff.
 
@@ -354,25 +370,32 @@ class ClassificationComponent(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Classification Plot".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
             hide_percentage (bool, optional): Hide percentage toggle. Defaults to False.
+            hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): Cutoff for prediction. Defaults to 0.5.
             percentage (bool, optional): Show percentage instead of counts. Defaults to True.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
         self.hide_cutoff, self.hide_percentage = hide_cutoff, hide_percentage
+        self.hide_selector = hide_selector
         self.cutoff, percentage = cutoff, percentage
         self.cutoff_name = 'classification-cutoff-' + self.name
+
+        self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
-    def _layout(self):
+    def layout(self):
         return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([self.selector.layout()], width=3), hide=self.hide_selector)
+            ], justify="end"),
             html.Div([
                 dcc.Loading(id="loading-classification-graph-"+self.name, 
                             children=[dcc.Graph(id='classification-graph-'+self.name)]),
@@ -409,19 +432,17 @@ class ClassificationComponent(ExplainerComponent):
             Output('classification-graph-'+self.name, 'figure'),
             [Input('classification-cutoff-'+self.name, 'value'),
              Input('classification-percentage-'+self.name, 'checked'),
-             Input('pos-label', 'value')],
-            [State('tabs', 'value')],
+             Input('pos-label-'+self.name, 'value')],
         )
-        def update_precision_graph(cutoff, percentage, pos_label, tab):
+        def update_precision_graph(cutoff, percentage, pos_label):
             return self.explainer.plot_classification(
                     cutoff=cutoff, percentage=percentage, pos_label=pos_label)
 
 
 class RocAucComponent(ExplainerComponent):
-    def __init__(self, explainer, title="ROC AUC Plot",
-                    header_mode="none", name=None, 
-                    hide_cutoff=False,
-                    cutoff=0.5):
+    def __init__(self, explainer, title="ROC AUC Plot", name=None, 
+                    hide_cutoff=False, hide_selector=False,
+                    pos_label=None, cutoff=0.5):
         """Show ROC AUC curve component
 
         Args:
@@ -429,23 +450,29 @@ class RocAucComponent(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "ROC AUC Plot".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
+            hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): default cutoff. Defaults to 0.5.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
-        self.hide_cutoff = hide_cutoff
+        self.hide_cutoff, self.hide_selector = hide_cutoff, hide_selector
         self.cutoff=cutoff
         self.cutoff_name = 'rocauc-cutoff-' + self.name
+        
+        self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
-    def _layout(self):
+    def layout(self):
         return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([self.selector.layout()], width=3), hide=self.hide_selector)
+            ], justify="end"),
             dcc.Loading(id="loading-roc-auc-graph-"+self.name, 
                                 children=[dcc.Graph(id='rocauc-graph-'+self.name)]),
             make_hideable(
@@ -465,18 +492,16 @@ class RocAucComponent(ExplainerComponent):
         @app.callback(
             Output('rocauc-graph-'+self.name, 'figure'),
             [Input('rocauc-cutoff-'+self.name, 'value'),
-             Input('pos-label', 'value'),
-             Input('tabs', 'value')],
+             Input('pos-label-'+self.name, 'value')],
         )
-        def update_precision_graph(cutoff, pos_label, tab):
+        def update_precision_graph(cutoff, pos_label):
             return self.explainer.plot_roc_auc(cutoff=cutoff, pos_label=pos_label)
 
 
 class PrAucComponent(ExplainerComponent):
-    def __init__(self, explainer, title="PR AUC Plot",
-                    header_mode="none", name=None,
-                    hide_cutoff=False,
-                    cutoff=0.5):
+    def __init__(self, explainer, title="PR AUC Plot", name=None,
+                    hide_cutoff=False, hide_selector=False,
+                    pos_label=None, cutoff=0.5):
         """Display PR AUC plot component
 
         Args:
@@ -484,23 +509,29 @@ class PrAucComponent(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "PR AUC Plot".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
             hide_cutoff (bool, optional): hide cutoff slider. Defaults to False.
+            hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): default cutoff. Defaults to 0.5.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
-        self.hide_cutoff = hide_cutoff
+        self.hide_cutoff, self.hide_selector = hide_cutoff, hide_selector
         self.cutoff = cutoff
         self.cutoff_name = 'prauc-cutoff-' + self.name
+
+        self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
-    def _layout(self):
+    def layout(self):
         return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([self.selector.layout()], width=3), hide=self.hide_selector)
+            ], justify="end"),
             dcc.Loading(id="loading-pr-auc-graph-"+self.name, 
                                 children=[dcc.Graph(id='prauc-graph-'+self.name)]),
             make_hideable(
@@ -519,8 +550,7 @@ class PrAucComponent(ExplainerComponent):
         @app.callback(
             Output('prauc-graph-'+self.name, 'figure'),
             [Input('prauc-cutoff-'+self.name, 'value'),
-             Input('pos-label', 'value')],
-            [State('tabs', 'value')],
+             Input('pos-label-'+self.name, 'value')],
         )
-        def update_precision_graph(cutoff, pos_label, tab):
+        def update_precision_graph(cutoff, pos_label):
             return self.explainer.plot_pr_auc(cutoff=cutoff, pos_label=pos_label)
\ No newline at end of file
