@@ -20,8 +20,8 @@ from .decisiontree_components import *
 
 
 class ClassifierModelStatsComposite(ExplainerComponent):
-    def __init__(self, explainer, title="Classification Stats", 
-                    header_mode="none", name=None,
+    def __init__(self, explainer, title="Classification Stats", name=None,
+                    hide_title=False, hide_selector=True, pos_label=None,
                     bin_size=0.1, quantiles=10, cutoff=0.5):
         """Composite of multiple classifier related components: 
             - precision graph
@@ -36,25 +36,28 @@ class ClassifierModelStatsComposite(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Decision Trees".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
+            hide_title (bool, optional): hide title. Defaults to False.          
+            hide_selector (bool, optional): hide all pos label selectors. Defaults to True.
+            pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             bin_size (float, optional): bin_size for precision plot. Defaults to 0.1.
             quantiles (int, optional): number of quantiles for precision plot. Defaults to 10.
             cutoff (float, optional): initial cutoff. Defaults to 0.5.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
-        self.precision = PrecisionComponent(explainer)
-        self.confusionmatrix = ConfusionMatrixComponent(explainer)
-        self.liftcurve = LiftCurveComponent(explainer)
-        self.classification = ClassificationComponent(explainer)
-        self.rocauc = RocAucComponent(explainer)
-        self.prauc = PrAucComponent(explainer)
+        self.hide_title = hide_title
 
-        self.cutoffpercentile = CutoffPercentileComponent(explainer)
+        self.precision = PrecisionComponent(explainer, hide_selector=hide_selector, pos_label=pos_label)
+        self.confusionmatrix = ConfusionMatrixComponent(explainer, hide_selector=hide_selector, pos_label=pos_label)
+        self.liftcurve = LiftCurveComponent(explainer, hide_selector=hide_selector, pos_label=pos_label)
+        self.classification = ClassificationComponent(explainer, hide_selector=hide_selector, pos_label=pos_label)
+        self.rocauc = RocAucComponent(explainer, hide_selector=hide_selector, pos_label=pos_label)
+        self.prauc = PrAucComponent(explainer, hide_selector=hide_selector, pos_label=pos_label)
+
+        self.cutoffpercentile = CutoffPercentileComponent(explainer, hide_selector=hide_selector, pos_label=pos_label)
         self.cutoffconnector = CutoffConnector(self.cutoffpercentile,
                 [self.precision, self.confusionmatrix, self.liftcurve, 
                  self.classification, self.rocauc, self.prauc])
@@ -64,9 +67,13 @@ class ClassifierModelStatsComposite(ExplainerComponent):
             self.classification, self.rocauc, self.prauc, self.cutoffpercentile,
             self.cutoffconnector)
 
-    def _layout(self):
-        return dbc.Container([
-            dbc.Row([dbc.Col([html.H2('Model Performance:')])]),
+    def layout(self):
+        return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([
+                     html.H2('Model Performance:')]), hide=self.hide_title),
+            ]),
             dbc.Row([
                 dbc.Col([
                     self.cutoffpercentile.layout(),
@@ -96,13 +103,13 @@ class ClassifierModelStatsComposite(ExplainerComponent):
                     self.prauc.layout()
                 ], md=6),
             ]),
-        ], fluid=True)
+        ])
 
 
 class RegressionModelStatsComposite(ExplainerComponent):
-    def __init__(self, explainer, title="Regression Stats", 
-                    header_mode="none", name=None,
-                    logs=False, pred_or_actual="vs_pred", ratio=False,
+    def __init__(self, explainer, title="Regression Stats", name=None,
+                    hide_title=False,
+                    logs=False, pred_or_actual="vs_pred", residuals='difference',
                     col=None):
         """Composite for displaying multiple regression related graphs:
 
@@ -115,34 +122,39 @@ class RegressionModelStatsComposite(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Regression Stats".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
+            hide_title (bool, optional): hide title. Defaults to False.
             logs (bool, optional): Use log axis. Defaults to False.
             pred_or_actual (str, optional): plot residuals vs predictions 
                         or vs y (actual). Defaults to "vs_pred".
-            ratio (bool, optional): Use residual ratios. Defaults to False.
+            residuals (str, {'difference', 'ratio', 'log-ratio'} optional): 
+                    How to calcualte residuals. Defaults to 'difference'.
             col ({str, int}, optional): Feature to use for residuals plot. Defaults to None.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
      
+        self.hide_title = hide_title
         assert pred_or_actual in ['vs_actual', 'vs_pred'], \
             "pred_or_actual should be 'vs_actual' or 'vs_pred'!"
 
         self.preds_vs_actual = PredictedVsActualComponent(explainer, logs=logs)
         self.modelsummary = RegressionModelSummaryComponent(explainer)
         self.residuals = ResidualsComponent(explainer, 
-                            pred_or_actual=pred_or_actual, ratio=ratio)
+                            pred_or_actual=pred_or_actual, residuals=residuals)
         self.residuals_vs_col = ResidualsVsColComponent(explainer, 
-                                    col=col, ratio=ratio)
+                                    col=col, residuals=residuals)
         self.register_components([self.preds_vs_actual, self.modelsummary,
                     self.residuals, self.residuals_vs_col])
 
-    def _layout(self):
-        return dbc.Container([
-            dbc.Row([dbc.Col([html.H2('Model Performance:')])]),
+    def layout(self):
+        return html.Div([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([
+                        html.H2('Model Performance:')]), hide=self.hide_title)
+            ]),
             dbc.Row([
                 dbc.Col([
                     self.preds_vs_actual.layout()
@@ -159,12 +171,12 @@ class RegressionModelStatsComposite(ExplainerComponent):
                     self.residuals_vs_col.layout()
                 ], md=6),
             ])
-        ], fluid=True)
+        ])
 
 
 class IndividualPredictionsComposite(ExplainerComponent):
-    def __init__(self, explainer, title="Individual Predictions",
-                        header_mode="none", name=None):
+    def __init__(self, explainer, title="Individual Predictions", name=None,
+                        hide_title=False, hide_selector=True):
         """Composite for a number of component that deal with individual predictions:
 
         - random index selector
@@ -178,31 +190,39 @@ class IndividualPredictionsComposite(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Individual Predictions".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
+            hide_title (bool, optional): hide title. Defaults to False.
+            hide_selector(bool, optional): hide all pos label selectors. Defaults to True.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
+
+        self.hide_title = hide_title
 
         if self.explainer.is_classifier:
-            self.index = ClassifierRandomIndexComponent(explainer)
+            self.index = ClassifierRandomIndexComponent(
+                            explainer, hide_selector=hide_selector)
         elif self.explainer.is_regression:
             self.index = RegressionRandomIndexComponent(explainer)
-        self.summary = PredictionSummaryComponent(explainer)
-        self.contributions = ShapContributionsGraphComponent(explainer)
-        self.pdp = PdpComponent(explainer)
-        self.contributions_list = ShapContributionsTableComponent(explainer)
+        self.summary = PredictionSummaryComponent(
+                            explainer, hide_selector=hide_selector)
+        self.contributions = ShapContributionsGraphComponent(
+                                explainer, hide_selector=hide_selector)
+        self.pdp = PdpComponent(
+                        explainer, hide_selector=hide_selector)
+        self.contributions_list = ShapContributionsTableComponent(
+                                        explainer, hide_selector=hide_selector)
 
         self.index_connector = IndexConnector(self.index, 
                 [self.summary, self.contributions, self.pdp, self.contributions_list])
 
-        self.register_components(self.index, self.summary, self.contributions, self.pdp, self.contributions_list, self.index_connector)
+        self.register_components(
+            self.index, self.summary, self.contributions, 
+            self.pdp, self.contributions_list, self.index_connector)
 
-    def _layout(self):
+    def layout(self):
         return html.Div([
-            dbc.Container([
                 dbc.Row([
                     dbc.Col([
                         self.index.layout()
@@ -227,13 +247,12 @@ class IndividualPredictionsComposite(ExplainerComponent):
                         html.Div([]),
                     ]),
                 ])
-            ], fluid=True),
         ])
 
 
 class ShapDependenceComposite(ExplainerComponent):
-    def __init__(self, explainer, title='Feature Dependence',
-                    header_mode="none", name=None,
+    def __init__(self, explainer, title='Feature Dependence', name=None,
+                    hide_selector=True,
                     depth=None, cats=True):
         """Composite of ShapSummary and ShapDependence component
 
@@ -242,23 +261,28 @@ class ShapDependenceComposite(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Feature Dependence".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
+            hide_selector (bool, optional): hide all pos label selectors. Defaults to True.
             depth (int, optional): Number of features to display. Defaults to None.
             cats (bool, optional): Group categorical features. Defaults to True.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
         
-        self.shap_summary = ShapSummaryComponent(self.explainer, depth=depth, cats=cats)
+        self.shap_summary = ShapSummaryComponent(
+                    self.explainer, 
+                    hide_selector=hide_selector, 
+                    depth=depth, cats=cats)
         self.shap_dependence = ShapDependenceComponent(
-                                    self.explainer, hide_cats=True, cats=cats)
-        self.connector = ShapSummaryDependenceConnector(self.shap_summary, self.shap_dependence)
+                    self.explainer, 
+                    hide_selector=hide_selector, hide_cats=True, 
+                    cats=cats)
+        self.connector = ShapSummaryDependenceConnector(
+                    self.shap_summary, self.shap_dependence)
         self.register_components(self.shap_summary, self.shap_dependence, self.connector)
 
-    def _layout(self):
+    def layout(self):
         return dbc.Container([
             dbc.Row([
                 dbc.Col([
@@ -272,8 +296,8 @@ class ShapDependenceComposite(ExplainerComponent):
 
 
 class ShapInteractionsComposite(ExplainerComponent):
-    def __init__(self, explainer, title='Feature Interactions',
-                    header_mode="none", name=None,
+    def __init__(self, explainer, title='Feature Interactions', name=None,
+                    hide_selector=True,
                     depth=None, cats=True):
         """Composite of InteractionSummaryComponent and InteractionDependenceComponent
 
@@ -282,41 +306,40 @@ class ShapInteractionsComposite(ExplainerComponent):
                         ClassifierExplainer() or RegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Feature Interactions".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
+            hide_selector (bool, optional): hide all pos label selectors. Defaults to True.
             depth (int, optional): Initial number of features to display. Defaults to None.
             cats (bool, optional): Initally group cats. Defaults to True.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
 
         self.interaction_summary = InteractionSummaryComponent(
-                explainer, depth=depth, cats=cats)
+                explainer, hide_selector=hide_selector, depth=depth, cats=cats)
         self.interaction_dependence = InteractionDependenceComponent(
-                explainer, cats=cats)
+                explainer, hide_selector=hide_selector, cats=cats, hide_cats=True)
         self.connector = InteractionSummaryDependenceConnector(
             self.interaction_summary, self.interaction_dependence)
         self.register_components(
             self.interaction_summary, self.interaction_dependence, self.connector)
         
-    def _layout(self):
+    def layout(self):
         return html.Div([
-            dbc.Row([
-                dbc.Col([
-                    self.interaction_summary.layout()
-                ], width=6),
-                dbc.Col([
-                    self.interaction_dependence.layout()
-                ], width=6),
-            ])
+                dbc.Row([
+                    dbc.Col([
+                        self.interaction_summary.layout()
+                    ], width=6),
+                    dbc.Col([
+                        self.interaction_dependence.layout()
+                    ], width=6),
+                ]) 
         ])
 
 
 class DecisionTreesComposite(ExplainerComponent):
-    def __init__(self, explainer, title="Decision Trees",
-                    header_mode="none", name=None):
+    def __init__(self, explainer, title="Decision Trees", name=None,
+                    hide_selector=True):
         """Composite of decision tree related components:
         
         - individual decision trees barchart
@@ -325,21 +348,25 @@ class DecisionTreesComposite(ExplainerComponent):
 
         Args:
             explainer (Explainer): explainer object constructed with either
-                        ClassifierExplainer() or RegressionExplainer()
+                        RandomForestClassifierExplainer() or RandomForestRegressionExplainer()
             title (str, optional): Title of tab or page. Defaults to 
                         "Decision Trees".
-            header_mode (str, optional): {"standalone", "hidden" or "none"}. 
-                        Defaults to "none".
             name (str, optional): unique name to add to Component elements. 
                         If None then random uuid is generated to make sure 
                         it's unique. Defaults to None.
+            hide_selector (bool, optional): hide all pos label selectors. Defaults to True.
         """
-        super().__init__(explainer, title, header_mode, name)
+        super().__init__(explainer, title, name)
         
-        self.index = ClassifierRandomIndexComponent(explainer)
-        self.trees = DecisionTreesComponent(explainer)
-        self.decisionpath_table = DecisionPathTableComponent(explainer)
-        self.decisionpath_graph = DecisionPathGraphComponent(explainer)
+        self.trees = DecisionTreesComponent(explainer, hide_selector=hide_selector)
+        self.decisionpath_table = DecisionPathTableComponent(explainer, hide_selector=hide_selector)
+
+        if explainer.is_classifier:
+            self.index = ClassifierRandomIndexComponent(explainer, hide_selector=hide_selector)
+        elif explainer.is_regression:
+            self.index = RegressionRandomIndexComponent(explainer)
+
+        self.decisionpath_graph = DecisionPathGraphComponent(explainer, hide_selector=hide_selector)
 
         self.index_connector = IndexConnector(self.index, 
             [self.trees, self.decisionpath_table, self.decisionpath_graph])
@@ -350,8 +377,21 @@ class DecisionTreesComposite(ExplainerComponent):
                 self.decisionpath_table, self.decisionpath_graph, 
                 self.index_connector, self.highlight_connector)
 
-    def _layout(self):
-        return dbc.Container([
+        # elif explainer.is_regression:
+        #     self.index = RegressionRandomIndexComponent(explainer)
+        #     self.decisionpath_graph = DecisionPathGraphComponent(explainer, hide_selector=hide_selector)# DummyComponent()
+        #     self.index_connector = IndexConnector(self.index, 
+        #             [self.trees, self.decisionpath_table])
+        #     self.highlight_connector = HighlightConnector(
+        #             self.trees, [self.decisionpath_table, self.decisionpath_graph])
+
+        #     self.register_components(
+        #             self.index, self.trees, self.decisionpath_table,
+        #             self.decisionpath_graph, self.index_connector, 
+        #             self.highlight_connector)
+        
+    def layout(self):
+        return html.Div([
             dbc.Row([
                 dbc.Col([
                     self.index.layout(),
@@ -372,4 +412,4 @@ class DecisionTreesComposite(ExplainerComponent):
                     self.decisionpath_graph.layout()
                 ])
             ]),
-        ])
\ No newline at end of file
+        ])
