@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__all__ = ['ExplainerDashboard', 
+__all__ = ['ExplainerTabsLayout',
+            'ExplainerPageLayout',
+            'ExplainerDashboard', 
             'JupyterExplainerDashboard',
             'ExplainerTab',
             'JupyterExplainerTab',
@@ -12,6 +14,7 @@ import requests
 import shortuuid
 import dash
 import dash_core_components as dcc
+import dash_html_components as html
 import dash_bootstrap_components as dbc
 
 from jupyter_dash import JupyterDash
@@ -20,13 +23,225 @@ import plotly.io as pio
 
 from .dashboard_components import *
 from .dashboard_tabs import *
+from .explainers import BaseExplainer
+
+
+def instantiate_component(component, explainer, **kwargs):
+    """Returns an instantiated ExplainerComponent.
+    If the component input is just a class definition, instantiate it with
+    explainer and k**wargs.
+    If it is already an ExplainerComponent instance then return it.
+    If it is any other instance with layout and register_components methods,
+    then add a name property and return it. 
+
+    Args:
+        component ([type]): Either a class definition or instance
+        explainer ([type]): An Explainer object that will be used to instantiate class definitions
+        kwargs: kwargs will be passed on to the instance
+
+    Raises:
+        ValueError: if component is not a subclass or instance of ExplainerComponent,
+                or is an instance without layout and register_callbacks methods
+
+    Returns:
+        [type]: instantiated component
+    """
+
+    if inspect.isclass(component) and issubclass(component, ExplainerComponent):
+        return component(explainer,  **kwargs)
+    elif isinstance(component, ExplainerComponent):
+        return component
+    elif (not inspect.isclass(component)
+          and hasattr(component, "layout")):
+        if not (hasattr(component, "name") and isinstance(component.name, str)):
+            component_name = shortuuid.ShortUUID().random(length=10)
+            print(f"Warning: setting {component}.name to {component_name}")
+            component.name = component_name
+        if not hasattr(component, "title"):
+            print(f"Warning: setting {component}.title to 'CustomTab'")
+            component.title = "Custom"
+        return component
+    else:
+        raise ValueError(f"{component} is not a valid component...")
+
+
+class ExplainerTabsLayout:
+    def __init__(self, explainer, tabs,
+                 title='Model Explainer',
+                 hide_title=False,
+                 hide_selector=False,
+                 block_selector_callbacks=False,
+                 pos_label=None,
+                 fluid=True,
+                 **kwargs):
+        """Generates a multi tab layout from a a list of ExplainerComponents.
+        If the component is a class definition, it gets instantiated first. If 
+        the component is not derived from an ExplainerComponent, then attempt
+        with duck typing to nevertheless instantiate a layout.
+
+        Args:
+            explainer ([type]): explainer
+            tabs (list[ExplainerComponent class or instance]): list of
+                ExplainerComponent class definitions or instances.
+            title (str, optional): [description]. Defaults to 'Model Explainer'.
+            hide_title (bool, optional): Hide the title. Defaults to False.
+            hide_selector (bool, optional): Hide the positive label selector. 
+                        Defaults to False.
+            block_selector_callbacks (bool, optional): block the callback of the
+                        pos label selector. Useful to avoid clashes when you
+                        have your own PosLabelSelector in your layout. 
+                        Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. 
+                        Defaults to explainer.pos_label
+            fluid (bool, optional): Stretch layout to fill space. Defaults to False.
+        """
+        self.title = title
+        self.hide_title = hide_title
+        self.hide_selector = hide_selector
+        self.block_selector_callbacks = block_selector_callbacks
+        if self.block_selector_callbacks:
+            self.hide_selector = True
+        self.fluid = fluid
+        
+        self.selector = PosLabelSelector(explainer, pos_label=pos_label)
+        self.tabs  = [instantiate_component(tab, explainer, **kwargs) for tab in tabs]
+        assert len(self.tabs) > 0, 'When passing a list to tabs, need to pass at least one valid tab!'
+
+        self.connector = PosLabelConnector(self.selector, self.tabs)
+   
+    def layout(self):
+        """returns a multitab layout plus ExplainerHeader"""
+        return dbc.Container([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([
+                        html.H1(self.title)
+                    ], width="auto"), hide=self.hide_title),
+                make_hideable(
+                    dbc.Col([
+                        self.selector.layout()
+                    ], md=3), hide=self.hide_selector),
+            ], justify="start"),
+            dcc.Tabs(id="tabs", value=self.tabs[0].name, 
+                        children=[dcc.Tab(label=tab.title, id=tab.name, value=tab.name,
+                                        children=tab.layout()) for tab in self.tabs]),
+        ], fluid=self.fluid)
+
+    def register_callbacks(self, app):
+        """Registers callbacks for all tabs"""
+        for tab in self.tabs:
+            try:
+                tab.register_callbacks(app)
+            except AttributeError:
+                print(f"Warning: {tab} does not have a register_callbacks method!")
+                
+        if not self.block_selector_callbacks:
+            if any([tab.has_pos_label_connector() for tab in self.tabs]):
+                print("Warning: detected PosLabelConnectors already in the layout. "
+                    "This may clash with the global pos label selector and generate duplicate callback errors. "
+                    "If so set block_selector_callbacks=True.")
+            self.connector.register_callbacks(app)
+
+    def calculate_dependencies(self):
+        """Calculates dependencies for all tabs"""
+        for tab in self.tabs:
+            try:
+                tab.calculate_dependencies()
+            except AttributeError:
+                print(f"Warning: {tab} does not have a calculate_dependencies method!")
+
+
+class ExplainerPageLayout(ExplainerComponent):
+    def __init__(self, explainer, component,
+                 title='Model Explainer',
+                 hide_title=False,
+                 hide_selector=False,
+                 block_selector_callbacks=False,
+                 pos_label=None,
+                 fluid=False,
+                 **kwargs):
+        """Generates a single page layout from a single ExplainerComponent.
+        If the component is a class definition, it gets instantiated. 
+
+        If the component is not derived from an ExplainerComponent, then tries
+        with duck typing to nevertheless instantiate a layout.
+
+
+        Args:
+            explainer ([type]): explainer
+            component (ExplainerComponent class or instance): ExplainerComponent 
+                        class definition or instance.
+            title (str, optional): [description]. Defaults to 'Model Explainer'.
+            hide_title (bool, optional): Hide the title. Defaults to False.
+            hide_selector (bool, optional): Hide the positive label selector.
+                        Defaults to False.
+            block_selector_callbacks (bool, optional): block the callback of the
+                        pos label selector. Useful to avoid clashes when you
+                        have your own PosLabelSelector in your layout. 
+                        Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. 
+                        Defaults to explainer.pos_label
+            fluid (bool, optional): Stretch layout to fill space. Defaults to False.
+        """
+        self.title = title
+        self.hide_title = hide_title
+        self.hide_selector = hide_selector
+        self.block_selector_callbacks = block_selector_callbacks
+        if self.block_selector_callbacks:
+            self.hide_selector = True
+        self.fluid = fluid
+        
+        self.selector = PosLabelSelector(explainer, pos_label=pos_label)
+        self.page  = instantiate_component(component, explainer, **kwargs) 
+        self.connector = PosLabelConnector(self.selector, self.page)
+        
+        self.fluid = fluid
+        
+    def layout(self):
+        """returns single page layout with an ExplainerHeader"""
+        return dbc.Container([
+            dbc.Row([
+                make_hideable(
+                    dbc.Col([
+                        html.H1(self.title)
+                    ], width="auto"), hide=self.hide_title),
+                make_hideable(
+                    dbc.Col([
+                        self.selector.layout()
+                    ], md=3), hide=self.hide_selector),
+            ], justify="start"),
+            self.page.layout()
+        ], fluid=self.fluid)
+
+    def register_callbacks(self, app):
+        """Register callbacks of page"""
+        try:
+            self.page.register_callbacks(app)
+        except AttributeError:
+            print(f"Warning: {self.page} does not have a register_callbacks method!")
+        if not self.block_selector_callbacks:
+            if hasattr(self.page, "has_pos_label_connector") and self.page.has_pos_label_connector():
+                print("Warning: detected PosLabelConnectors already in the layout. "
+                    "This may clash with the global pos label selector and generate duplicate callback errors. "
+                    "If so set block_selector_callbacks=True.")
+            self.connector.register_callbacks(app)
+
+    def calculate_dependencies(self):
+        """Calculate dependencies of page"""
+        try:
+            self.page.calculate_dependencies()
+        except AttributeError:
+            print(f"Warning: {self.page} does not have a calculate_dependencies method!")
 
 
 class ExplainerDashboard:
     def __init__(self, explainer=None, tabs=None,
                  title='Model Explainer',
+                 hide_header=False,
                  header_hide_title=False,
                  header_hide_selector=False,
+                 block_selector_callbacks=False,
+                 pos_label=None,
                  fluid=True,
                  mode="dash",
                  width=1000,
@@ -77,8 +292,15 @@ class ExplainerDashboard:
             explainer(): explainer object
             tabs(): single component or list of components
             title(str, optional): title of dashboard, defaults to 'Model Explainer'
+            hide_header (bool, optional) hide the header (title+selector), defaults to False.
             header_hide_title(bool, optional): hide the title, defaults to False
             header_hide_selector(bool, optional): hide the positive class selector for classifier models, defaults, to False
+            block_selector_callbacks (bool, optional): block the callback of the
+                        pos label selector. Useful to avoid clashes when you
+                        have your own PosLabelSelector in your layout. 
+                        Defaults to False.
+            pos_label ({int, str}, optional): initial pos label. 
+                        Defaults to explainer.pos_label
             mode(str, {'dash', 'inline' , 'jupyterlab', 'external'}, optional): 
                 type of dash server to start. 'inline' runs in a jupyter notebook output cell. 
                 'jupyterlab' runs in a jupyterlab pane. 'external' runs in an external tab
@@ -96,24 +318,32 @@ class ExplainerDashboard:
             shap_interaction(bool, optional): include InteractionsTab if model allows it, defaults to True.
             decision_trees(bool, optional): include DecisionTreesTab if model allows it, defaults to True.
         """
+        print("Building ExplainerDashboard..", flush=True)  
+        if hide_header:
+            header_hide_title = True
+            header_hide_selector = True
         self.mode, self.width, self.height = mode, width, height
-        self.header_hide_title, self.header_hide_selector = \
-            header_hide_title, header_hide_selector
+        self.hide_header, self.header_hide_title, self.header_hide_selector = \
+            hide_header, header_hide_title, header_hide_selector
         self.external_stylesheets = external_stylesheets
         self.server, self.url_base_pathname = server, url_base_pathname
         
         self.app = self._get_dash_app()
         self.app.title = title
+
+        assert isinstance(explainer, BaseExplainer), \
+            ("explainer should be an instance of BaseExplainer, such as "
+            "ClassifierExplainer or RegressionExplainer!")
         
         if tabs is None:
             tabs = []
             if shap_interaction and not explainer.interactions_should_work:
                 print("For this type of model and model_output interactions don't "
-                          "work, so setting shap_interaction=False...")
+                          "work, so setting shap_interaction=False...", flush=True)
                 shap_interaction = False
             if decision_trees and not hasattr(explainer, 'decision_trees'):
                 print("the explainer object has no decision_trees property. so "
-                        "setting decision_trees=False...")
+                        "setting decision_trees=False...", flush=True)
                 decision_trees = False
         
             if importances:
@@ -131,22 +361,29 @@ class ExplainerDashboard:
 
         if isinstance(tabs, list) and len(tabs)==1:
             tabs = tabs[0]
-                    
+        print("Generating layout...")  
         if isinstance(tabs, list):
             tabs = [self._convert_str_tabs(tab) for tab in tabs]
             explainer_layout = ExplainerTabsLayout(explainer, tabs, title, 
                             hide_title=header_hide_title, 
                             hide_selector=header_hide_selector, 
+                            block_selector_callbacks=block_selector_callbacks,
+                            pos_label=pos_label,
                             fluid=fluid)
         else:
             tabs = self._convert_str_tabs(tabs)
             explainer_layout = ExplainerPageLayout(explainer, tabs, title, 
                             hide_title=header_hide_title, 
                             hide_selector=header_hide_selector, 
+                            block_selector_callbacks=block_selector_callbacks,
+                            pos_label=pos_label,
                             fluid=fluid)
 
         self.app.layout = explainer_layout.layout()
+
+        print("Calculating dependencies...", flush=True)  
         explainer_layout.calculate_dependencies()
+        print("registering callbacks...", flush=True)
         explainer_layout.register_callbacks(self.app)
 
     def _convert_str_tabs(self, component):
@@ -214,10 +451,10 @@ class ExplainerDashboard:
         self.port = port
         
         if self.mode == 'dash':
-            print(f"Starting ExplainerDashboard on http://localhost:{port}")
+            print(f"Starting ExplainerDashboard on http://localhost:{port}", flush=True)
             self.app.run_server(port=port, **kwargs)
         elif self.mode == 'external':
-            print(f"Starting ExplainerDashboard on http://localhost:{port}")
+            print(f"Starting ExplainerDashboard on http://localhost:{port}", flush=True)
             self.app.run_server(port=port, mode=self.mode, **kwargs)
         elif self.mode in ['inline', 'jupyterlab']:
             self.app.run_server(port=port, mode=self.mode, 
@@ -357,41 +594,41 @@ class InlineExplainer:
         component.register_callbacks(app)
         self._run_app(app)
     
+    @delegates_kwargs(ImportancesComponent)
+    @delegates_doc(ImportancesComponent)
     def importances(self, title='Importances', **kwargs):
         """Runs model_summary tab inline in notebook"""
-        comp = ImportancesComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp = ImportancesComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     def model_stats(self, title='Models Stats', **kwargs):
         """Runs model_stats inline in notebook"""
         if self._explainer.is_classifier:
-            comp = ClassifierModelStatsComposite(self._explainer, 
-                    header_mode="hidden", **kwargs)
+            comp = ClassifierModelStatsComposite(self._explainer, **kwargs)
         elif self._explainer.is_regression:
-            comp = RegressionModelStatsComposite(self._explainer, 
-                header_mode="hidden", **kwargs)
+            comp = RegressionModelStatsComposite(self._explainer, **kwargs)
         self._run_component(comp, title)
 
+    @delegates_kwargs(PredictionSummaryComponent)
+    @delegates_doc(PredictionSummaryComponent)
     def prediction(self,  title='Prediction', **kwargs):
         """Show contributions (permutation or shap) inline in notebook"""
-        comp = PredictionSummaryComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = PredictionSummaryComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     def random_index(self, title='Random Index', **kwargs):
         """show random index selector inline in notebook"""
         if self._explainer.is_classifier:
-            comp = ClassifierRandomIndexComponent(self._explainer, 
-                    header_mode="hidden", **kwargs)
+            comp = ClassifierRandomIndexComponent(self._explainer, **kwargs)
         elif self._explainer.is_regression:
-            comp = RegressionRandomIndexComponent(self._explainer, 
-                    header_mode="hidden", **kwargs)
+            comp = RegressionRandomIndexComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
+    @delegates_kwargs(PdpComponent)
+    @delegates_doc(PdpComponent)
     def pdp(self, title="Partial Dependence Plots", **kwargs):
         """Show contributions (permutation or shap) inline in notebook"""
-        comp = PdpComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = PdpComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     
@@ -417,48 +654,42 @@ class InlineExplainerTabs(InlineExplainerComponent):
     @delegates_doc(ImportancesTab)
     def importances(self,  title='Importances', **kwargs):
         """Show contributions (permutation or shap) inline in notebook"""
-        tab = ImportancesTab(self._explainer, 
-                header_mode="standalone", **kwargs)
+        tab = ImportancesTab(self._explainer, **kwargs)
         self._run_component(tab, title)
 
     @delegates_kwargs(ModelSummaryTab)
     @delegates_doc(ModelSummaryTab)
     def modelsummary(self, title='Model Summary', **kwargs):
         """Runs model_summary tab inline in notebook"""
-        tab = ModelSummaryTab(self._explainer, 
-                header_mode="standalone", **kwargs)
+        tab = ModelSummaryTab(self._explainer, **kwargs)
         self._run_component(tab, title)
 
     @delegates_kwargs(ContributionsTab)
     @delegates_doc(ContributionsTab)
     def contributions(self,  title='Contributions', **kwargs):
         """Show contributions (permutation or shap) inline in notebook"""
-        tab = ContributionsTab(self._explainer, 
-                header_mode="standalone", **kwargs)
+        tab = ContributionsTab(self._explainer, **kwargs)
         self._run_component(tab, title)
 
     @delegates_kwargs(ShapDependenceTab)
     @delegates_doc(ShapDependenceTab)
     def dependence(self, title='Shap Dependence', **kwargs):
         """Runs shap_dependence tab inline in notebook"""
-        tab = ShapDependenceTab(self._explainer, 
-                header_mode="standalone", **kwargs)
+        tab = ShapDependenceTab(self._explainer, **kwargs)
         self._run_component(tab, title)
 
     @delegates_kwargs(ShapInteractionsTab)
     @delegates_doc(ShapInteractionsTab)
     def interactions(self, title='Shap Interactions', **kwargs):
         """Runs shap_interactions tab inline in notebook"""
-        tab = ShapInteractionsTab(self._explainer, 
-                header_mode="standalone", **kwargs)
+        tab = ShapInteractionsTab(self._explainer, **kwargs)
         self._run_component(tab, title)
 
     @delegates_kwargs(DecisionTreesTab)
     @delegates_doc(DecisionTreesTab)
     def decisiontrees(self, title='Decision Trees', **kwargs):
         """Runs shap_interactions tab inline in notebook"""
-        tab = DecisionTreesTab(self._explainer, 
-                header_mode="standalone", **kwargs)
+        tab = DecisionTreesTab(self._explainer, **kwargs)
         self._run_component(tab, title)
 
 
@@ -468,16 +699,14 @@ class InlineShapExplainer(InlineExplainerComponent):
     @delegates_doc(ShapDependenceComposite)
     def overview(self, title='Shap Overview', **kwargs):
         """Runs shap_dependence tab inline in notebook"""
-        comp = ShapDependenceComposite(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = ShapDependenceComposite(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ShapSummaryComponent)
     @delegates_doc(ShapSummaryComponent)
     def summary(self, title='Shap Summary', **kwargs):
         """Show shap summary inline in notebook"""
-        comp = ShapSummaryComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = ShapSummaryComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ShapDependenceComponent)
@@ -485,46 +714,42 @@ class InlineShapExplainer(InlineExplainerComponent):
     def dependence(self, title='Shap Dependence', **kwargs):
         """Show shap summary inline in notebook"""
         
-        comp = ShapDependenceComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = ShapDependenceComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ShapInteractionsComposite)
     @delegates_doc(ShapInteractionsComposite)
     def interaction_overview(self, title='Interactions Overview', **kwargs):
         """Runs shap_dependence tab inline in notebook"""
-        comp = ShapInteractionsComposite(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = ShapInteractionsComposite(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(InteractionSummaryComponent)
     @delegates_doc(InteractionSummaryComponent)
     def interaction_summary(self, title='Shap Interaction Summary', **kwargs):
         """show shap interaction summary inline in notebook"""
-        comp =InteractionSummaryComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp =InteractionSummaryComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(InteractionDependenceComponent)
     @delegates_doc(InteractionDependenceComponent)
     def interaction_dependence(self, title='Shap Interaction Dependence', **kwargs):
         """show shap interaction dependence inline in notebook"""
-        comp =InteractionDependenceComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp =InteractionDependenceComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ShapContributionsGraphComponent)
     @delegates_doc(ShapContributionsGraphComponent)
     def contributions_graph(self,  title='Contributions', **kwargs):
         """Show contributions (permutation or shap) inline in notebook"""
-        comp = ShapContributionsGraphComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = ShapContributionsGraphComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ShapContributionsTableComponent)
     @delegates_doc(ShapContributionsTableComponent)
     def contributions_table(self,  title='Contributions', **kwargs):
         """Show contributions (permutation or shap) inline in notebook"""
-        comp = ShapContributionsTableComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = ShapContributionsTableComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
 
@@ -533,8 +758,7 @@ class InlineClassifierExplainer(InlineExplainerComponent):
     @delegates_doc(ClassifierModelStatsComposite)
     def model_stats(self, title='Models Stats', **kwargs):
         """Runs model_stats inline in notebook"""
-        comp = ClassifierModelStatsComposite(self._explainer, 
-                    header_mode="hidden", **kwargs)
+        comp = ClassifierModelStatsComposite(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(PrecisionComponent)
@@ -542,14 +766,14 @@ class InlineClassifierExplainer(InlineExplainerComponent):
     def precision(self, title="Precision Plot", **kwargs):
         """shows precision plot"""
         assert self._explainer.is_classifier
-        comp = PrecisionComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp = PrecisionComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ConfusionMatrixComponent)
     @delegates_doc(ConfusionMatrixComponent)
     def confusion_matrix(self, title="Confusion Matrix", **kwargs):
         """shows precision plot"""
-        comp= ConfusionMatrixComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp= ConfusionMatrixComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(LiftCurveComponent)
@@ -557,7 +781,7 @@ class InlineClassifierExplainer(InlineExplainerComponent):
     def lift_curve(self, title="Lift Curve", **kwargs):
         """shows precision plot"""
         assert self._explainer.is_classifier
-        comp = LiftCurveComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp = LiftCurveComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ClassificationComponent)
@@ -565,7 +789,7 @@ class InlineClassifierExplainer(InlineExplainerComponent):
     def classification(self, title="Classification", **kwargs):
         """shows precision plot"""
         assert self._explainer.is_classifier
-        comp = ClassificationComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp = ClassificationComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(RocAucComponent)
@@ -573,7 +797,7 @@ class InlineClassifierExplainer(InlineExplainerComponent):
     def roc_auc(self, title="ROC AUC Curve", **kwargs):
         """shows precision plot"""
         assert self._explainer.is_classifier
-        comp = RocAucComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp = RocAucComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(PrAucComponent)
@@ -581,7 +805,7 @@ class InlineClassifierExplainer(InlineExplainerComponent):
     def pr_auc(self, title="PR AUC Curve", **kwargs):
         """shows precision plot"""
         assert self._explainer.is_classifier
-        comp = PrAucComponent(self._explainer, header_mode="hidden", **kwargs)
+        comp = PrAucComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
 
@@ -591,33 +815,31 @@ class InlineRegressionExplainer(InlineExplainerComponent):
     @delegates_doc(RegressionModelStatsComposite)
     def model_stats(self, title='Models Stats', **kwargs):
         """Runs model_stats inline in notebook"""
-
-        comp = RegressionModelStatsComposite(self._explainer, 
-                    header_mode="hidden", **kwargs)
+        comp = RegressionModelStatsComposite(self._explainer, **kwargs)
         self._run_component(comp, title)
     
     @delegates_kwargs(PredictedVsActualComponent)
     @delegates_doc(PredictedVsActualComponent)
     def pred_vs_actual(self, title="Predicted vs Actual", **kwargs):
         "shows predicted vs actual for regression"
-        assert self.explainer.is_regression
-        comp = PredictedVsActualComponent(self._explainer, header_mode="hidden", **kwargs)
+        assert self._explainer.is_regression
+        comp = PredictedVsActualComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ResidualsComponent)
     @delegates_doc(ResidualsComponent)
     def residuals(self, title="Residuals", **kwargs):
         "shows residuals for regression"
-        assert self.explainer.is_regression
-        comp = ResidualsComponent(self._explainer, header_mode="hidden", **kwargs)
+        assert self._explainer.is_regression
+        comp = ResidualsComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(ResidualsVsColComponent)
     @delegates_doc(ResidualsVsColComponent)
     def residuals_vs_col(self, title="Residuals vs col", **kwargs):
         "shows residuals vs col for regression"
-        assert self.explainer.is_regression
-        comp = ResidualsVsColComponent(self._explainer, header_mode="hidden", **kwargs)
+        assert self._explainer.is_regression
+        comp = ResidualsVsColComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
 
@@ -626,31 +848,28 @@ class InlineDecisionTreesExplainer(InlineExplainerComponent):
     @delegates_doc(DecisionTreesComposite)
     def overview(self, title="Decision Trees", **kwargs):
         """shap decision tree composite inline in notebook"""
-        comp = DecisionTreesComposite(self._explainer, header_mode="hidden", **kwargs)
+        comp = DecisionTreesComposite(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(DecisionTreesComponent)
     @delegates_doc(DecisionTreesComponent)
     def decisiontrees(self, title='Decision Trees', **kwargs):
         """Runs decision_trees tab inline in notebook"""
-        comp = DecisionTreesComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = DecisionTreesComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(DecisionPathTableComponent)
     @delegates_doc(DecisionPathTableComponent)
     def decisionpath_table(self, title='Decision path', **kwargs):
         """Runs decision_trees tab inline in notebook"""
-        comp = DecisionPathTableComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = DecisionPathTableComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
     @delegates_kwargs(DecisionPathTableComponent)
     @delegates_doc(DecisionPathTableComponent)
     def decisionpath_graph(self, title='Decision path', **kwargs):
         """Runs decision_trees tab inline in notebook"""
-        comp = DecisionPathTableComponent(self._explainer, 
-                header_mode="hidden", **kwargs)
+        comp = DecisionPathTableComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
    
